@@ -53,7 +53,7 @@ def clone(histref: bh.Histogram | None = None) -> bh.Histogram:
     """
     if histref is None:
         return bh.Histogram()
-    return bh.Histogram(*histref.axes, storage=histref._storage_type())
+    return bh.Histogram(*histref.axes, storage=histref.storage_type())
 
 
 def _blocked_sa(
@@ -308,7 +308,7 @@ class AggHistogram(DaskMethodsMixin):
     @property
     def _storage_type(self) -> type[bh.storage.Storage]:
         """Storage type of the histogram."""
-        return self.histref._storage_type
+        return self.histref.storage_type
 
     @property
     def ndim(self) -> int:
@@ -617,7 +617,7 @@ def _partitioned_histogram(
 ) -> PartitionedHistogram:
     name = f"hist-on-block-{tokenize(data, histref, weights, sample, split_every)}"
     data_is_df = is_dataframe_like(data[0])
-    data_is_dak = is_awkward_like(data[0])
+    data_is_dak = is_dask_awkward_like(data[0])
     _weight_sample_check(*data, weights=weights)
 
     # Single awkward array object.
@@ -723,7 +723,7 @@ def to_dask_array(agghist: AggHistogram, flow: bool = False, dd: bool = False) -
     shape = agghist.histref.shape
     if flow:
         shape = tuple(i + 2 for i in shape)
-    int_storage = agghist.histref._storage_type in (
+    int_storage = agghist.histref.storage_type in (
         bh.storage.Int64,
         bh.storage.AtomicInt64,
     )
@@ -832,8 +832,7 @@ def factory(
     split_every : int, optional
         How many blocks to use in each split during aggregation.
     keep_partitioned : bool, optional
-        If ``True``, return the partitioned histogram collection
-        instead of an aggregated histogram.
+        **Deprecated argument**. Use :py:func:`partitioned_factory`.
 
     Returns
     -------
@@ -911,6 +910,18 @@ def partitioned_factory(
     weights: DaskCollection | None = None,
     sample: DaskCollection | None = None,
 ) -> PartitionedHistogram:
+    """Daskified Histogram collection factory function; keep partitioned.
+
+    This is a version of the :py:func:`factory` function that **remains
+    partitioned**. The :py:func:`factory` function includes a step in the
+    task graph that aggregates all partitions into a single final
+    histogram.
+
+    See Also
+    --------
+    dask_histogram.factory
+
+    """
     if histref is None and axes is None:
         raise ValueError("Either histref or axes must be defined.")
     if histref is not None and storage is not None:
@@ -925,7 +936,7 @@ def partitioned_factory(
     )
 
 
-def is_awkward_like(x: Any) -> bool:
+def is_dask_awkward_like(x: Any) -> bool:
     """Check if an object is Awkward collection like.
 
     Parameters
